@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: dh_exchange.c,v 1.10 2000/09/19 18:14:40 nisse Exp $ */
+ * $Id: dh_exchange.c,v 1.12 2001/02/25 22:38:18 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -43,15 +43,14 @@ init_dh_instance(struct dh_method *m,
   mpz_init(self->e);
   mpz_init(self->f);
   mpz_init(self->secret);
-#if 0
-  mpz_init(self->K);
-#endif
+
+  self->K = NULL;
   
   self->method = m;
   self->hash = MAKE_HASH(m->H);
   self->exchange_hash = NULL;
 
-  debug("init_dh_instance()\n"
+  debug("init_dh_instance\n"
 	" V_C: %pS\n", c->versions[CONNECTION_CLIENT]);
   debug(" V_S: %pS\n", c->versions[CONNECTION_SERVER]);
   debug(" I_C: %xS\n", c->literal_kexinits[CONNECTION_CLIENT]);
@@ -229,16 +228,3 @@ dh_process_server_msg(struct dh_instance *self,
   return key;
 }
 
-#if 0
-int
-dh_verify_server_msg(struct dh_instance *self,
-		     struct verifier *v)
-{
-  dh_hash_digest(self);
-
-  return VERIFY(v,
-		self->hash->hash_size, self->exchange_hash->data,
-		self->signature->length, self->signature->data);
-}
-#endif
-
