@@ -55,7 +55,11 @@ spawn_lshd () {
     ../lshd -h $HOSTKEY --interface=localhost \
 	-p $PORT $SERVERFLAGS --pid-file lshd.$$.pid &
 
-    at_exit 'kill `cat lshd.$$.pid`; rm -f lshd.$$.pid'
+    # lshd may catch the ordinary TERM signal, leading to timing
+    # problems when the next lshd process tries to bind the port.
+    # So we kill it harder.
+
+    at_exit 'kill -9 `cat lshd.$$.pid`; rm -f lshd.$$.pid'
 
     # Wait a little for lshd to start
     for delay in 1 1 1 1 1 5 5 5 20 20 60 60; do
