@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.c,v 1.50 2001/02/25 22:38:22 nisse Exp $ */
+ * $Id: werror.c,v 1.51 2001/03/25 12:31:10 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -555,7 +555,11 @@ fatal(const char *format, ...)
   va_end(args);
   werror_flush();
 
+#if WITH_GCOV
+  exit(255);
+#else
   abort();
+#endif
 }
 
 static unsigned
